==> dokuwiki_0.0.20060309.orig.tar.gz: dokuwiki-2006-03-09/lib/plugins/usermanager/lang/cs/lang.php <==
<?php
/**
 * Czech language file
 *
 * @author Tomas Valenta <t.valenta@sh.cvut.cz>
 */
 
$lang['menu'] = 'Správce uživatelů'; 
 
// custom language strings for the plugin
$lang['noauth']      = '(autorizace uživatelů není k dispozici)';
$lang['nosupport']   = '(správa uživatelů není podporována)';

$lang['badauth']     = 'chybna metoda autorizace';     // should never be displayed!

$lang['user_id']     = 'Uživatel';
$lang['user_pass']   = 'Heslo';
$lang['user_name']   = 'Celé jméno';
$lang['user_mail']   = 'Email';
$lang['user_groups'] = 'Skupiny';

$lang['field']       = 'Položka';
$lang['value']       = 'Hodnota';
$lang['add']         = 'Přidat';
$lang['delete']      = 'Smazat';
$lang['delete_selected'] = 'Smazat vybrané';
$lang['edit']        = 'Upravit';
$lang['edit_prompt'] = 'Upravit uživatele';
$lang['modify']      = 'Uložit změny';
$lang['search']      = 'Hledání';
$lang['search_prompt'] = 'Prohledat';
$lang['clear']       = 'Zrušit hledací filtr';
$lang['filter']      = 'Filtr';

$lang['summary']     = 'Zobrazuji uživatele %1$d-%2$d z %3$d nalezených. Celkem %4$d uživatelů.';
$lang['nonefound']   = 'Žadný uživatel nenalezen. Celkem %d uživatelů.';
$lang['delete_ok']   = '%d uživatelů smazáno';
$lang['delete_fail'] = '%d uživatelů nelze zmazat.';
$lang['update_ok']   = 'Uživatel upraven';
$lang['update_fail'] = 'Úprava uživatele selhala';
$lang['update_exists'] = 'Jméno nelze změnit, jelikož (%s) již existuje (ostatní změny budou provedeny).';

$lang['start']  = 'první';
$lang['prev']   = 'předchozí';
$lang['next']   = 'další';
$lang['last']   = 'poslední';

==> dokuwiki_0.0.20070626b.orig.tar.gz: dokuwiki-2007-06-26b/lib/plugins/usermanager/lang/cs/lang.php <==
<?php
/**
 * Czech language file
 *
 * @author Tomas Valenta <t.valenta@sh.cvut.cz>
 */
 
$lang['menu'] = 'Správa uživatelů'; 
 
// custom language strings for the plugin
$lang['noauth']      = '(autentizace uživatelů není k dispozici)';
$lang['nosupport']   = '(správa uživatelů není podporována)';

$lang['badauth']     = 'chybná metoda autentizace';     // should never be displayed!

$lang['user_id']     = 'Uživatel';
$lang['user_pass']   = 'Heslo';
$lang['user_name']   = 'Celé jméno';
$lang['user_mail']   = 'Email';
$lang['user_groups'] = 'Skupiny';

$lang['field']       = 'Položka';
$lang['value']       = 'Hodnota';
$lang['add']         = 'Přidat';
$lang['delete']      = 'Smazat';
$lang['delete_selected'] = 'Smazat vybrané';
$lang['edit']        = 'Upravit';
$lang['edit_prompt'] = 'Upravit uživatele';
$lang['modify']      = 'Uložit změny';
$lang['search']      = 'Hledání';
$lang['search_prompt'] = 'Prohledat';
$lang['clear']       = 'Zrušit hledací filtr';
$lang['filter']      = 'Filtr';

$lang['summary']     = 'Zobrazuji uživatele %1$d-%2$d z %3$d nalezených. Celkem %4$d uživatelů.';
$lang['nonefound']   = 'Žadný uživatel nenalezen. Celkem %d uživatelů.';
$lang['delete_ok']   = '%d uživatelů smazáno';
$lang['delete_fail'] = '%d uživatelů nelze smazat.';
$lang['update_ok']   = 'Uživatel upraven';
$lang['update_fail'] = 'Úprava uživatele selhala';
$lang['update_exists'] = 'Jméno nelze změnit, jelikož zadané uživatelské jméno (%s) již existuje (ostatní změny ale budou provedeny).';

$lang['start']  = 'první';
$lang['prev']   = 'předchozí';
$lang['next']   = 'další';
$lang['last']   = 'poslední';

// added after 2006-03-09 release
$lang['edit_usermissing'] = 'Vybraný uživate nebyl nalezen, zadané uživatelského mohlo být smazáno nebo změněno.';
